local frames = {}
local pressed = false
local addonname = "|c002FC5D0AutoMacro: |r"

local function MakeMovable(frame)
	frame:SetMovable(true)
	frame:EnableMouse(true)
	frame:RegisterForDrag("LeftButton")
	frame:SetScript("OnDragStart", frame.StartMoving)
	frame:SetScript("OnDragStop", frame.StopMovingOrSizing)
end

-- Config frame
local config = {}
config.main = CreateFrame("Frame", "AutoMacroConfigFrame", UIPanel)
config.main:SetFrameStrata("DIALOG")
config.main:SetSize(300,200)
config.main:SetPoint("CENTER")
config.main.texture = config.main:CreateTexture(nil, "BACKGROUND")
config.main.texture:SetAllPoints(config.main)
config.main.texture:SetTexture(0,0,0,0.5)
MakeMovable(config.main)
config.main:Hide()

-- Load the saved variables
config.main:RegisterEvent("ADDON_LOADED")
config.main:SetScript("OnEvent", function(self, event, ...)
	if (event == "ADDON_LOADED") and (... == "AutoMacro") then
		AutoMacroDB = AutoMacroDB or {}
		AutoMacroDB.default = [[#showtooltip
/use [@mouseover,exists][] <spell>]]
		config.box.EditBox:SetText(AutoMacroDB.macro or AutoMacroDB.default)
		self:UnregisterEvent("ADDON_LOADED")
	end
end)

config.box = CreateFrame("ScrollFrame", "AutoMacroConfigEditBox", config.main, "InputScrollFrameTemplate")
config.box:SetPoint("TOPLEFT", config.main, "TOPLEFT", 15, -65)
config.box:SetPoint("BOTTOMRIGHT", config.main, "BOTTOMRIGHT", -15, 45)
config.box.EditBox:SetMaxLetters(255)
config.box.EditBox:SetAllPoints()
config.box.CharCount:Hide()

config.title = config.main:CreateFontString("AutoMacroConfigTitle", "OVERLAY", "GameFontNormal")
config.title:SetPoint("TOP", 0, 0)
config.title:SetText("AutoMacro configuration")

config.desc = config.main:CreateFontString("AutoMacroConfigDesc", "OVERLAY", "GameFontWhiteSmall")
config.desc:SetPoint("TOPLEFT", config.main, "TOPLEFT", 10, -20)
config.desc:SetWidth(config.main:GetWidth() - 20)
config.desc:SetJustifyH("LEFT")
config.desc:SetText("Type below the macro you want to create with AutoMacro. Use <spell> where the name of the spell clicked should be replaced.")

config.ok = CreateFrame("Button", "AutoMacroConfigOkay", config.main, "UIPanelButtonTemplate")
config.ok:SetSize(100,20)
config.ok:SetPoint("BOTTOM", config.main, "BOTTOM", 0, 10)
config.ok:SetText(_G["OKAY"])  
config.ok:SetScript("OnClick", function() 
	AutoMacroDB.macro = config.box.EditBox:GetText()
	config.main:Hide() 
end)

-- Frames over the spells
for i = 1, 12 do
	local spell = _G["SpellButton" .. i]
	frames[i] = CreateFrame("Frame", "AutoMacroFrame" .. i, SpellBookFrame)
	frames[i]:SetFrameStrata("HIGH")
	frames[i]:SetAllPoints(spell)
	frames[i]:Hide()
	frames[i]:SetScript("OnMouseDown", function()
		local slot = SpellBook_GetSpellBookSlot(spell)
		local _, id = GetSpellBookItemInfo(slot, "spell")
		local name, _, icon = GetSpellInfo(id)
		icon = gsub(icon, "Interface\\Icons\\", "")
		icon = gsub(icon, "INTERFACE\\ICONS\\", "")
		local macro = gsub(AutoMacroDB.macro, "<spell>", name)
		local exists = GetMacroIndexByName(name)
		if exists ~= 0 then
			DEFAULT_CHAT_FRAME:AddMessage(addonname .. "There's already a macro named \"" .. name .. "\"")
			else
			local index = CreateMacro(name, icon, macro, 1)
			if (index) then DEFAULT_CHAT_FRAME:AddMessage(addonname .. "Macro created succesfully!") end
		end
	end)
end

-- ON/OFF Button
local button = CreateFrame("Button", "AutoMacroButton", SpellBookFrame, "UIPanelButtonTemplate")
button:RegisterForClicks("AnyUp")
button:SetText("AutoMacro")
button:SetSize(120,18)
button:SetPoint("TOPRIGHT", SpellBookFrameCloseButton, "TOPLEFT", 4 , -6)
button:SetScript("OnClick", function(self, but)
	if (but == "LeftButton") then
		if (not pressed) then
			pressed = true
			button:LockHighlight()
			button:SetText("AutoMacro ON")
			for i = 1, 12 do frames[i]:Show() end
			else
			pressed = false
			button:UnlockHighlight()
			button:SetText("AutoMacro")
			for i = 1, 12 do frames[i]:Hide() end
		end
		else
		config.main:Show()
	end
end)
button:SetScript("OnEnter", function(self)
	GameTooltip:SetOwner(self, "ANCHOR_TOPLEFT")
	GameTooltip:SetText("Right click for options", _, _, _, _, true)
	GameTooltip:Show()
end)
button:SetScript("OnLeave", function(self)
	GameTooltip:Hide()
end)